@@ -33,9 +33,10 @@
 #  define KMEDIAPLAYER_DEPRECATED_NO_EXPORT KMEDIAPLAYER_NO_EXPORT KMEDIAPLAYER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMEDIAPLAYER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMEDIAPLAYER_NO_DEPRECATED
+#    define KMEDIAPLAYER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
